use ratparam
use preg_rat_params
prepare @clear@all  % T DAYS AUCBB CV
CINT=1; TSTART=0; % Used for bolus dosing, not needed here
GSTART=7; % Day after start of exposure when gestation begins
					% GSTART should be high enough to reach periodicity or steady state
TSTOP=GSTART*24; % Don't simulate pregnancy for juvenile animal/growth period
TCHNG=TSTOP+1; % TCHNG turns off dosing if < TSTOP, for analyzing stop-dose studies
doses = [50 160 500]; % mg/kg/d
tres = [0, doses];	% First row of results table

%for BWINIT=[50 100 150 200 300 400]/1000;
for BWINIT=[50 250]/1000; 
	rres = BWINIT;	% Start row of results table
	for DOSEF=[50 160 500]
		start @nocallback
		sscheck = _cv(GSTART*24)/_cv((GSTART-1)*24) - 1	% check for periodicity/SS, should be ~ 0
		rres = [rres, (_aucbb(TSTOP) - _aucbb(TSTOP-24))/24]; % AUC for last day of exposure
	end
	%plot(_t/24,_cv)
	tres = [tres; rres];	% Append results row
end
tres
TSTOP=(GSTART+21)*24; TCHNG=TSTOP+1; % Allows 21 days of gestation
gdosestart = (GSTART+6)*24; % Time (h) to start calculating pregnancy average concentration
gesthr=TSTOP-gdosestart; % Total hours over which pregnancy dose is calculated

"Simulations for gestational exposure P2/F2A" 
BWs=[324.3 305.4 281.5]/1000; % Initial BWs for each exposure group, from Table 53
% Below calculates mean intake (dose rate) for each group, from values for GD 6-20 in Table 67.
doses=[mean([55.1 52.5 51.4 50.9]), mean([170.9 167.8 162.9 165.4]), mean([514.3 524.6 479.7 457.8])];
nfet=[17 19 14]; % # of fetuses for each dose group, chose to approximately match GD 20 BW
p2f2a=[]; % empty results array
for n=1:3;
	BWINIT=BWs(n); DOSEF=doses(n); NUMFET=nfet(n); % Assign group input values
	start @nocallback
	sscheck = _cv(GSTART*24)/_cv((GSTART-1)*24) - 1	% check for periodicity/SS @ GSTART, should be ~ 0
	% Below appends inputs and results to array
	p2f2a = [p2f2a; [BWINIT, DOSEF, NUMFET, _bw(TSTOP-24), (_aucbb(find(_t==TSTOP))-_aucbb(find(_t==gdosestart)))/gesthr]];  % AUC/time = avg conc
	%plot(_t/24,_cv)
	end
p2f2a

"Simulations for gestational exposure P2/F2B"
BWs=[370.6 353.6 318.7]/1000; % Initial BWs for each exposure group, from Table 56
% Below calculates mean intake (dose rate) for each group, from values for GD 6-20 in Table 69.
doses=[mean([53.7 51.2 47.9 44.6]), mean([165.6 164.8 152.9 143.5]), mean([508.5 491.1 460.4 406.5])];
nfet=[18 19 12]; % # of fetuses for each dose group, chose to approximately match GD 20 BW
p2f2b=[]; % empty results array
for n=1:3;
	BWINIT=BWs(n); DOSEF=doses(n); NUMFET=nfet(n);  % Assign group input values
	start @nocallback
	sscheck = _cv(GSTART*24)/_cv((GSTART-1)*24) - 1	% check for periodicity/SS @ GSTART, should be ~ 0
% Below appends inputs and results to array
	p2f2b = [p2f2b; [BWINIT, DOSEF, NUMFET, _bw(TSTOP-24), (_aucbb(find(_t==TSTOP))-_aucbb(find(_t==gdosestart)))/gesthr]];  % AUC/time = avg conc
	%plot(_t/24,_cv)
	end
p2f2b
